Sirm

Struct Sirm 

pub struct Sirm {
Show 13 fields pub base: u64, pub info: u32, pub control: u32, pub req_payload_size: u64, pub req_leader_size: u32, pub req_trailer_size: u32, pub max_leader_size: u32, pub max_trailer_size: u32, pub payload_size: u64, pub payload_count: u32, pub transfer1_size: u32, pub transfer2_size: u32, pub max_payload_transfer: u32,
}
Streaming Interface Register Map — per-stream-channel configuration.

Fields

base: u64info: u32control: u32req_payload_size: u64req_leader_size: u32req_trailer_size: u32max_leader_size: u32max_trailer_size: u32payload_size: u64payload_count: u32transfer1_size: u32transfer2_size: u32max_payload_transfer: u32

Implementations

Source

impl Sirm

pub fn read_from<T: UsbTransfer>( control: &mut ControlChannel<T>, base: u64, ) -> Result<Self, U3vError>

Read the SIRM from the device at the given base address (from SBRM).

Source

impl Sirm

pub fn enable<T: UsbTransfer>( &self, control: &mut ControlChannel<T>, ) -> Result<(), U3vError>

Enable streaming by setting bit 0 of the SIRM control register.

pub fn disable<T: UsbTransfer>( &self, control: &mut ControlChannel<T>, ) -> Result<(), U3vError>

Disable streaming by clearing bit 0 of the SIRM control register.

pub fn configure<T: UsbTransfer>( &self, control: &mut ControlChannel<T>, payload_size: u64, leader_size: u32, trailer_size: u32, ) -> Result<(), U3vError>

Write the requested payload, leader, and trailer sizes to the SIRM.